@@ -277,9 +277,10 @@ class ChatHub:
                 if response.get("type") == 1 and response["arguments"][0].get(
                     "messages",
                 ):
-                    yield False, response["arguments"][0]["messages"][0][
-                        "adaptiveCards"
-                    ][0]["body"][0].get("text")
+                    resp_txt = response["arguments"][0]["messages"][0]["adaptiveCards"][
+                        0
+                    ]["body"][0].get("text")
+                    yield False, resp_txt
                 elif response.get("type") == 2:
                     final = True
                     yield True, response
@@ -378,7 +379,10 @@ async def main():
     session = create_session()
     while True:
         print("\nYou:")
-        question = await get_input_async(session=session)
+        if not args.enter_once:
+            question = await get_input_async(session=session)
+        else:
+            question = input()
         print()
         if question == "!exit":
             break
